<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="da" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config.py" line="67"/>
        <source>Behavior</source>
        <translation>Opførsel</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Automatically save documents</source>
        <translation>Gem automatisk dokumenter</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Restore window geometry</source>
        <translation>Gendan vinduesgeometri</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Open external links in ReText window</source>
        <translation>Åbn eksterne links i ReText-vinduet</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Highlight current line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Show line numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Tab key inserts spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Tabulation width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Display right margin at column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Icon theme name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Stylesheet file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Markdown syntax extensions (comma-separated)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="102"/>
        <source>Help</source>
        <translation type="unfinished">Hjælp</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Use live preview by default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="config.py" line="34"/>
        <source>(none)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="41"/>
        <source>Select file to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="dialogs.py" line="44"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Indtast lokalitetsnavn (f.eks. da_DK)</translation>
    </message>
    <message>
        <location filename="dialogs.py" line="49"/>
        <source>Set as default</source>
        <translation>Sæt som standard</translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <location filename="fakevimeditor.py" line="64"/>
        <source>No write since last change (add ! to override)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fakevimeditor.py" line="121"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextTab</name>
    <message>
        <location filename="tab.py" line="115"/>
        <source>New document</source>
        <translation>Nyt dokument</translation>
    </message>
    <message>
        <location filename="tab.py" line="121"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>Kunne ikke indlæse filens indhold, dobbeltcheck at du har det &lt;a href=&quot;%s&quot;&gt;nødvendige modul&lt;/a&gt; installeret.</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="window.py" line="69"/>
        <source>File toolbar</source>
        <translation>Fil-værktøjslinie</translation>
    </message>
    <message>
        <location filename="window.py" line="71"/>
        <source>Edit toolbar</source>
        <translation>Redigering-værktøjslinie</translation>
    </message>
    <message>
        <location filename="window.py" line="73"/>
        <source>Search toolbar</source>
        <translation>Søge-værktøjslinie</translation>
    </message>
    <message>
        <location filename="window.py" line="77"/>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <location filename="window.py" line="80"/>
        <source>Open</source>
        <translation>Åben</translation>
    </message>
    <message>
        <location filename="window.py" line="89"/>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <location filename="window.py" line="83"/>
        <source>Set encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="93"/>
        <source>Save as</source>
        <translation>Gem som</translation>
    </message>
    <message>
        <location filename="window.py" line="99"/>
        <source>Print</source>
        <translation>Udskrift</translation>
    </message>
    <message>
        <location filename="window.py" line="102"/>
        <source>Print preview</source>
        <translation>Udskriftsvisning</translation>
    </message>
    <message>
        <location filename="window.py" line="104"/>
        <source>View HTML code</source>
        <translation>Vis HTML-kode</translation>
    </message>
    <message>
        <location filename="window.py" line="109"/>
        <source>Find text</source>
        <translation>Find tekst</translation>
    </message>
    <message>
        <location filename="window.py" line="113"/>
        <source>Preview</source>
        <translation>Forhåndsvisning</translation>
    </message>
    <message>
        <location filename="window.py" line="123"/>
        <source>Live preview</source>
        <translation>Live-forhåndsvisning</translation>
    </message>
    <message>
        <location filename="window.py" line="136"/>
        <source>Fullscreen mode</source>
        <translation>Fuldskærmsvisning</translation>
    </message>
    <message>
        <location filename="window.py" line="503"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="146"/>
        <source>Quit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <location filename="window.py" line="149"/>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <location filename="window.py" line="151"/>
        <source>Redo</source>
        <translation>Gendan</translation>
    </message>
    <message>
        <location filename="window.py" line="153"/>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <location filename="window.py" line="155"/>
        <source>Cut</source>
        <translation>Klip</translation>
    </message>
    <message>
        <location filename="window.py" line="157"/>
        <source>Paste</source>
        <translation>Indsæt</translation>
    </message>
    <message>
        <location filename="window.py" line="167"/>
        <source>Enable</source>
        <translation>Aktiver</translation>
    </message>
    <message>
        <location filename="window.py" line="168"/>
        <source>Set locale</source>
        <translation>Sæt sprogindstillinger</translation>
    </message>
    <message>
        <location filename="window.py" line="169"/>
        <source>Use WebKit renderer</source>
        <translation>Anvend WebKit-fremviser</translation>
    </message>
    <message>
        <location filename="window.py" line="172"/>
        <source>Next</source>
        <translation>Næste</translation>
    </message>
    <message>
        <location filename="window.py" line="174"/>
        <source>Previous</source>
        <translation>Foregående</translation>
    </message>
    <message>
        <location filename="window.py" line="176"/>
        <source>Get help online</source>
        <translation>Find hjælp online</translation>
    </message>
    <message>
        <location filename="window.py" line="177"/>
        <source>About ReText</source>
        <translation>Om ReText</translation>
    </message>
    <message>
        <location filename="window.py" line="180"/>
        <source>About Qt</source>
        <translation>Om Qt</translation>
    </message>
    <message>
        <location filename="window.py" line="200"/>
        <source>Bold</source>
        <translation>Fed</translation>
    </message>
    <message>
        <location filename="window.py" line="202"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location filename="window.py" line="204"/>
        <source>Underline</source>
        <translation>Understregning</translation>
    </message>
    <message>
        <location filename="window.py" line="212"/>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <location filename="window.py" line="216"/>
        <source>Symbols</source>
        <translation>Symboler</translation>
    </message>
    <message>
        <location filename="window.py" line="223"/>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <location filename="window.py" line="224"/>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <location filename="window.py" line="225"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="window.py" line="228"/>
        <source>Open recent</source>
        <translation>Åben seneste</translation>
    </message>
    <message>
        <location filename="window.py" line="241"/>
        <source>Export</source>
        <translation>Eksport</translation>
    </message>
    <message>
        <location filename="window.py" line="262"/>
        <source>Spell check</source>
        <translation>Stavekontrol</translation>
    </message>
    <message>
        <location filename="window.py" line="270"/>
        <source>Default markup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="273"/>
        <source>Formatting</source>
        <translation>Formattering</translation>
    </message>
    <message>
        <location filename="window.py" line="313"/>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <location filename="window.py" line="315"/>
        <source>Case sensitively</source>
        <translation>Skelnen mellem store og små bogstaver</translation>
    </message>
    <message>
        <location filename="window.py" line="442"/>
        <source>New document</source>
        <translation>Nyt dokument</translation>
    </message>
    <message>
        <location filename="window.py" line="591"/>
        <source>Please, save the file somewhere.</source>
        <translation>Gem venligst filen et sted.</translation>
    </message>
    <message>
        <location filename="window.py" line="171"/>
        <source>Show directory</source>
        <translation>Vis mappe</translation>
    </message>
    <message>
        <location filename="window.py" line="711"/>
        <source>Select one or several files to open</source>
        <translation>Vælg en eller flere filer, der skal åbnes</translation>
    </message>
    <message>
        <location filename="window.py" line="711"/>
        <source>Supported files</source>
        <translation>Understøttede filer</translation>
    </message>
    <message>
        <location filename="window.py" line="711"/>
        <source>All files (*)</source>
        <translation>Alle filer (*)</translation>
    </message>
    <message>
        <location filename="window.py" line="750"/>
        <source>Select file encoding from the list:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="770"/>
        <source>Plain text (*.txt)</source>
        <translation>Ren tekst (*.txt)</translation>
    </message>
    <message>
        <location filename="window.py" line="773"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s-filer</translation>
    </message>
    <message>
        <location filename="window.py" line="844"/>
        <source>Save file</source>
        <translation>Gem fil</translation>
    </message>
    <message>
        <location filename="window.py" line="799"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Kan ikke gemme filen, fordi den er skrivebeskyttet!</translation>
    </message>
    <message>
        <location filename="window.py" line="834"/>
        <source>Export document to ODT</source>
        <translation>Eksporter dokument til ODT</translation>
    </message>
    <message>
        <location filename="window.py" line="834"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>OpenDocument-tekstfiler (*.odt)</translation>
    </message>
    <message>
        <location filename="window.py" line="844"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML-filer (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="window.py" line="866"/>
        <source>Export document to PDF</source>
        <translation>Eksporter dokument til PDF</translation>
    </message>
    <message>
        <location filename="window.py" line="866"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF-filer (*.pdf)</translation>
    </message>
    <message>
        <location filename="window.py" line="883"/>
        <source>Print document</source>
        <translation>Udskriv dokument</translation>
    </message>
    <message>
        <location filename="window.py" line="904"/>
        <source>Export document</source>
        <translation>Eksporter dokument</translation>
    </message>
    <message>
        <location filename="window.py" line="923"/>
        <source>Failed to execute the command:</source>
        <translation>Kunne ikke udføre kommandoen:</translation>
    </message>
    <message>
        <location filename="window.py" line="1030"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Dokumentet er blevet ændret.
Ønsker du at gemme dine ændringer?</translation>
    </message>
    <message>
        <location filename="window.py" line="1055"/>
        <source>HTML code</source>
        <translation>HTML-kode</translation>
    </message>
    <message>
        <location filename="window.py" line="1066"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Enkel men stærk editor til Markdown og reStructuredText</translation>
    </message>
    <message>
        <location filename="window.py" line="1066"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Forfatter: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="window.py" line="1066"/>
        <source>Website</source>
        <translation>Hjemmeside</translation>
    </message>
    <message>
        <location filename="window.py" line="1066"/>
        <source>Markdown syntax</source>
        <translation>Markdown-syntaks</translation>
    </message>
    <message>
        <location filename="window.py" line="1066"/>
        <source>reStructuredText syntax</source>
        <translation>reStructuredText-syntaks</translation>
    </message>
    <message>
        <location filename="window.py" line="1009"/>
        <source>Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="95"/>
        <source>Next tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="97"/>
        <source>Previous tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="128"/>
        <source>Table mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="131"/>
        <source>FakeVim mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="992"/>
        <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1000"/>
        <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1005"/>
        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="105"/>
        <source>Change editor font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="107"/>
        <source>Change preview font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1066"/>
        <source>ReText %s (using PyMarkups %s)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
